<template>
  <div class="process-panel">
    <div class="nodeName">
      <!-- 流程选择 -->
      <span class="title">{{$t('submitTo')}}</span>
      <span class="use-tip" @click.stop="hiddenSuggest()">
          {{$t('commonOpinions')}}
          <i class="fa fa-caret-down common-opinion-icon"></i>
      </span>
      <div class="refer-check">
        <template v-for="(item, index) in nodesList">
          <label :key="index" class="list-data mint-checkbox">
            <input
              type="checkbox"
              :id="item.nodeId"
              :value="item.nodeId"
              :key="'c'+index"
              v-model="nextNodeIds"
              class="mint-checkbox-input"
            />
            <span class="mint-checkbox-core"></span>
            <label :for="item.nodeId" :key="'l'+index">{{item.nodeName}}</label>
          </label>
        </template>
      </div>
    </div>
    <div class="comment-box">
      <div class="wrap-left">
        <!-- 意见 -->
        <div>
          <mt-field 
            class="opinion"
            v-show="signMode == 'TEXT'" 
            :placeholder="$t('fillComments')"
            maxlength="140"
            type="textarea" 
            rows="5" 
            v-model="attitude">
          </mt-field>

          <!--手签-->
          <div class="idea-canvas" v-show="signMode == 'SIGN'">
            <canvas
              id="canvas"
              :width="canvasWidth"
              :height="canvasHeight"
              style="border:1px solid rgba(229,229,229,1);background:rgba(246,246,246,1);"
              @touchstart='touchStart' 
              @touchmove='touchMove' 
              @touchend='touchEnd'
              ref="canvas"
            ></canvas>
          </div>
        </div>
      </div>
      <!-- 工具操作（右边） -->
      <div class="wrap-right">
        <!-- <span class="use-tip" @click="hiddenSuggest()">
          常用意见
          <i class="fa fa-caret-down common-opinion-icon"></i>
        </span> -->
        <span @click="changeSignMode" class="sign">
          {{$t('signature')}}
        </span>
        <span @click="onSubmit" class="sign normal">
          {{$t('confirm')}}
        </span>
        <span v-if="signMode == 'SIGN'" class="sign primary" @click="clear" size="small">{{$t('rewrite')}}</span>
      </div>

      <!-- 常用意见操作 -->
      <div class="use-suggest" v-if="suggestBoxVisible" style="">
        <div class="sug-data" v-if="allSuggests">
          <div class="sug-box">
            <span
              class="data-row"
              v-for="(item, index) in allSuggests"
              :key="index"
              @click="putData(item.content)"
            >
              <span :class="[showDelAndEdit?'suggest-name-one':'suggest-name-two']">{{item.content}}</span>
              <span class="icon" v-if="showDelAndEdit">
                <span>
                  <i class="fa fa-trash-o" @click="deleteSuggestion(item.id)"></i>
                </span>
                <span class="icon-two">
                  <i
                    class="fa fa-pencil-square-o"
                    @click.stop.prevent="editSuggestion(item.id, item.content)"
                  ></i>
                </span>
              </span>
            </span>
          </div>
        </div>
        <div class="sug-btn" v-if="!showInput">
          <div class="btns">
            <span @click="showInputBox">
              <img src="../assets/images/add.png">
              <span>{{$t('addCommonComments')}}</span>
            </span>
            <span @click="editSuggest">
              <img src="../assets/images/jump.png">
              <span>{{$t('editComment')}}</span>
            </span>
          </div>
        </div>
        <div class="sug-new" v-if="showEditFirst">
          <div class="new-input">
            <input type="text" v-model="input" />
          </div>
          <div class="keep-cancel">
            <span @click="cancelAddSuggest(1)">{{$t('cancel')}}</span>
            <span @click="addSuggestion">{{$t('verify')}}</span>
          </div>
        </div>
        <div class="sug-new" v-if="showEditSecond">
          <div class="new-input">
            <input type="text" v-model="inputSecond" />
          </div>
          <div class="keep-cancel">
            <span @click="cancelAddSuggest(2)">{{$t('cancel')}}</span>
            <span @click="updateSuggestion">{{$t('verify')}}</span>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import { Toast } from 'mint-ui';
import API from "@/api.js";
export default {
  props: ["act","openParams","buildFormData","approvers"],
  data: function() {
    return {
      signMode: "TEXT",//意见填写模式，SIGN:手写 TEXT：文本输入
      suggestBoxVisible: false,
      attitude: "",
      showInput: false, //是否展示添加常见意见框 开始false
      showEditFirst: false, //展示编辑意见框 

      showDelAndEdit: false,  //开始false
      allSuggests: [],
      showEditSecond: false,  //开始false
      input:'',
      inputSecond: "",
      opinionId: "", //更新意见信息的ID
      currentNodeId: "",
      existCanvas: false, //是否存在手写签名
      nodesList:[],
      nextNodeIds:[],
      canvasHeight: window.innerHeight*0.6 - 88 - 42, //弹框占屏幕60% 88为提交至和回退至的高度 42为手签重写确认按钮的高度
      canvasWidth: window.innerWidth,
    };
  },
  created() {
    
  },

  mounted() {
    this.getSuggest();
    this.setNodes();
    // 准备手写签名画布
    this.canvas = this.$refs.canvas; //指定canvas
    this.ctx = this.canvas.getContext("2d"); //设置2D渲染区域
    this.ctx.fillStyle = "#fff";
    this.ctx.fillRect(0, 0, 500, 142);
    //this.ctx.lineWidth = 1;//设置线的宽度
  },
  updated(){
    this.resizeCanvas();
  },
  methods: {
    //清除画布数据
    clear() {
      this.ctx.clearRect(0, 0, this.ctx.canvas.width, this.ctx.canvas.height);
      this.existCanvas = false;
    },
    resizeCanvas() {
      this.canvas.width = window.innerWidth;
    },

    touchStart(ev) {
      ev = ev || event
      ev.preventDefault()
      this.canvasMoveUse = true;
      let rect = this.$refs.canvas.getBoundingClientRect();
      if (ev.touches.length == 1) {
        let obj = {
          x: ev.targetTouches[0].clientX,
          y: ev.targetTouches[0].clientY,
        }
        const canvasX = obj.x - this.$refs.canvas.offsetLeft;
        const canvasY = obj.y - rect.top;
        this.ctx.beginPath();  // 移动的起点
        this.ctx.moveTo(canvasX, canvasY);
      }
    },
    touchMove(ev) {
      if (this.canvasMoveUse) {
        // 只有允许移动时调用
        let rect = this.$refs.canvas.getBoundingClientRect();
        if (ev.touches.length == 1) {
          let obj = {
            x: ev.targetTouches[0].clientX,
            y: ev.targetTouches[0].clientY,
          }
          let canvasX;
          let canvasY;
          canvasX = obj.x - this.$refs.canvas.offsetLeft;
          canvasY = obj.y -  rect.top;
          this.ctx.lineTo(canvasX, canvasY);
          this.ctx.stroke();
        }
      }
    },
    touchEnd() {
      this.existCanvas = true;
      this.canvasMoveUse = false;
    },
 
    getSignImageData() {
      if (this.existCanvas) {
        //判断是否存在手写签名
        let pJson;
        let canvas = document.getElementById("canvas");
        let signature = canvas.toDataURL("image/png");
        let str = signature.replace("data:image/png;base64,", "");
        pJson = {
          type: "image/png;base64",
          data: str
        };
        return pJson;
      }else {
        return false;
      }
      
    },

    //保存重新编辑的意见
    updateSuggestion() {
      let opId = this.opinionId,
          opinion = this.inputSecond;
      API.updateOpinion(this.$root.user.id, opId, opinion, {
        onSucess: response => {
          if (response.data.data) {
            let id = response.data.data.id;
            let content = response.data.data.content;
            for (let i = 0; i < this.allSuggests.length; i++) {
              if (this.allSuggests[i].id == id) {
                this.allSuggests[i].content = content;
                this.inputSecond = "";
              }
            }
          }
        }
      });
    },

    //重新编辑意见
    editSuggestion(id, content) {
      this.inputSecond = content;
      this.opinionId = id;
    },

    //删除意见
    deleteSuggestion(id) {
      let opId = id;
      API.deleteComments(this.$root.user.id, opId, {
        onSucess: response => {
          if (response.data.data) {
            let delId = response.data.data.id;
            let allSug = this.allSuggests;
            for (let i = 0; i < allSug.length; i++) {
              if (allSug[i].id == delId) {
                allSug.splice(i, 1);
                i--;
              }
            }
            this.allSuggest = allSug;
          }
        }
      });
    },

    //添加意见
    addSuggestion() {
      let opinion = this.input;
      API.addCommonOpinions(this.$root.user.id, opinion, {
        onSucess: response => {
          let newSuggest = response.data.data;
          this.allSuggests.push(newSuggest);
          this.input = "";
        }
      });
    },

    // 选中的数据放进文本框中
    putData(content) {
      if (this.showDelAndEdit == false) {
        if (!this.attitude) {
          this.attitude = content;
        } else if (this.attitude) {
          this.attitude = this.attitude + "," + content;
        }
      }
    },

    editSuggest() {
      this.showInput = true;
      this.showEditFirst = false;
      this.showEditSecond = true;
      this.showDelAndEdit = true;
    },

    cancelAddSuggest(num) {
      if (num == 1) {
        this.showInput = false;
        this.showDelAndEdit = false;
        this.showEditFirst = false;
      } else if (num == 2) {
        this.showInput = false;
        this.showDelAndEdit = false;
        this.showEditSecond = false;
      }
    },

    showInputBox() {
      this.showInput = true;
      this.showEditFirst = true;
    },

    //隐藏小意见框
    hiddenSuggest() {
      this.suggestBoxVisible = !this.suggestBoxVisible;
    },
    changeSignMode() {
      if (this.signMode == "TEXT") {
        this.signMode = "SIGN";
      }
      else {
        this.signMode = "TEXT";
      }
    },

    //获取返回的数据
    getSuggest() {
      this.$api.getCommonOpinions(this.$root.user.id, {
        onSucess: response => {
          this.allSuggests = response.data.data;
        }
      });
    },

    //节点
    setNodes() {
      let obj =  JSON.parse(this.act.reminderNodesData);
      this.nodesList = obj.data;
    },

     //提交
    onSubmit() {
      let pJson = this.getSignImageData()
      let formData = this.buildFormData;
      formData.stateId = this.stateId;
      let docId = formData.id,
          id = formData.id;
      let formId = formData.formId;
      let document = {
        applicationId: this.$root.appid,
        currentNodeId: this.currentNodeId,
        docId: docId,
        document: formData,
        formId: formId,
        id: id,
        nodertIds:this.nextNodeIds,
        parentId: "",
        templateForm: "",
        viewId: ""
      };
      if (pJson) {
        //手写签名
        document.signatureJson = JSON.stringify(pJson);
      }
      document.attitude = this.attitude;
      this.$api.remindFlow(this.$root.appid, docId, document,{
        onSucess: response => {
          let status;
          if(response.data.errcode == 0) {
            status = 'SUCCESS';
            this.$emit("closePopup",status);
            Toast({
              message: response.data.data,
              iconClass: 'fa fa-check fa-2x'
            });
          }else if(response.data.errcode==4001){
            status = 'ERROR';
            this.$emit("closePopup",status)
            this.$emit("closePopup",status);
            Toast({
              message: response.data.errmsg,
              iconClass: 'fa fa-close fa-2x'
            });
          }
        }
      });
    },
    
  }
};
</script>